import {Component, Input, OnInit} from '@angular/core';
import {CommunityInfo} from '../../openaireLibrary/connect/community/communityInfo';
import {CommunityService} from '../../openaireLibrary/connect/community/community.service';
import {Subscription} from 'rxjs';
import {OpenaireEntities} from "../../openaireLibrary/utils/properties/searchFields";

@Component({
  selector: 'community-info',
  template: `
    <ul *ngIf="community" class="uk-tab uk-margin-remove-bottom uk-margin-medium-top uk-flex uk-flex-center uk-flex-left@m" uk-tab>
      <li [class.uk-active]="tab === 'profile'"><a  routerLink="../profile">Profile</a></li>
      <li [class.uk-active]="tab === 'organizations'"><a  routerLink="../organizations">Organizations</a></li>
      <li [class.uk-active]="tab === 'projects'"><a  routerLink="../projects">{{openAIREEntities.PROJECTS}}</a></li>
      <li [class.uk-active]="tab === 'content-providers'"><a  routerLink="../content-providers">{{openAIREEntities.DATASOURCES}}</a></li>
      <li *ngIf="community.type !='ri'" [class.uk-active]="tab === 'subjects'"><a  routerLink="../subjects">Subjects</a></li>
      <li [class.uk-active]="tab === 'zenodo-communities'"><a  routerLink="../zenodo-communities">Zenodo Communities</a></li>
    </ul>
  `
})
export class CommunityInfoComponent implements OnInit {
  @Input()
  public type: string;
  @Input()
  public tab: "profile"| "organizations" | "projects" | "content-providers" | "subjects" | "zenodo-communities" = 'profile';
  public community: CommunityInfo;
  public openAIREEntities = OpenaireEntities;
  private sub;

  constructor(private communityService: CommunityService) {
  }

  ngOnInit() {
    this.sub =this.communityService.getCommunityAsObservable().subscribe(community => {
      this.community = community;
    });
  }
  ngOnDestroy() {
     if (this.sub instanceof Subscription) {
       this.sub.unsubscribe();
    }
  }
}
